Network Resource Vocabulary
===========================

This is a repository to version NRV -- network resource vocabulary.

``pip install nrv``

Usage
-----

::

    import nrv

    nrv.list_versions()

    nrv.get_version('v1')

Development
-----------

Create a PR to suggested new version, name it as new file, with ``v$``,
where ``$`` is a natural number.
